---------------------------------------------------------------------------
------------------  XMO data Conversion and print 	 ----------------------
---------------------------------------------------------------------------
function MotionData_xmo_Exporter(OUT_xmoFilePath,Motions_data)
	---------------------------------------------------------------------------
	------------------  Input data	----------------------
	---------------------------------------------------------------------------
	-- WARNING SI units used for the import: m,s
	-- OUT_xmoFilePath -> path where to save the file:close
	-- Motions_data -> Table with data regarding the motion.
	--		Example table:	
	--			Motions_data={
	--				[1]={
	--					Label="Nameof the motion"
	--					TimeHistory={
	--						[1]={
	--							Time=0							-- s
	--							Transf3=Transf3 				-- IPS transf
	--							Name='Name of the Waypoint 1' 	-- (OPTIONAL)
	--							}
	--						...
	--						[step]=data
	--						}
	--					}
	--				...
	--				[motion_Num]=motion_data
	--				}
	
	local XMO_header='<?xml version=\"1.0\"?>\n'
	
	local XmlFileHnd = io.open(OUT_xmoFilePath, "w+")
	XmlFileHnd:write(XMO_header)
	XmlFileHnd:write('<Motions>\n')
	--
	--for im, motion_data in ipairs(Motions_data) do
	for motion_Num, motion_data in pairs(Motions_data) do
		local Motion_prepend='\t'
		XmlFileHnd:write(Motion_prepend..'<Motion name=\"'..motion_data.Label..'\">\n')
		for step,data in ipairs(motion_data.TimeHistory) do
			local Frame_prepend='\t\t'
			-- What to replicate
			--<Frame name="Waypoint 2">
			--	<Quaternion e1="-0.70704627016159838" e2="-0.0030853092074259493" e3="0.70710011649694982" e4="-0.0092557402372146734" />
			--	<Translation x="0.060919600000000011" y="-99.322699999999998" z="-257.57399999999996" />
			--	<Time t="1" />
			--</Frame>
			-- WARNING: 
			-- Translation is in mm
			local WP_Name
			if data.Name then WP_Name=data.Name
			else WP_Name='Step '..tostring(step) end
			XmlFileHnd:write(Frame_prepend..'<Frame name=\"'..WP_Name..'\">\n')
			-- Data extraction
				local prepend='\t\t\t'
				----------------------------------
				--		Quaternion
				----------------------------------
				local Q=data.Transf3.R:toQuaternion()
				
				-- quaternion
				--[[
				--<Quaternion e1="Q.qw" e2="Q.qx" e3="Q.qy" e4="Q.qz" />
				local quaternion_line=prepend..'<Quaternion'
				local quaternion_line=quaternion_line..' e1=\"'..tostring(Q.qw)..'\" '
				local quaternion_line=quaternion_line..' e2=\"'..tostring(Q.qx)..'\" '
				local quaternion_line=quaternion_line..' e3=\"'..tostring(Q.qy)..'\" '
				local quaternion_line=quaternion_line..' e4=\"'..tostring(Q.qz)..'\" '
				local quaternion_line=quaternion_line..'/>\n'
				XmlFileHnd:write(quaternion_line)
				--]]

				local iRPY=data.Transf3.R:calcRPY()
				local iRPY_line=prepend..'<RPY'
				iRPY_line=iRPY_line..' roll=\"'..tostring(iRPY[0])..'\" '
				iRPY_line=iRPY_line..' pitch=\"'..tostring(iRPY[1])..'\" '
				iRPY_line=iRPY_line..' yaw=\"'..tostring(iRPY[2])..'\" '
				iRPY_line=iRPY_line..'/>\n'
				XmlFileHnd:write(iRPY_line)
				

				
				----------------------------------
				--		Translation
				----------------------------------
				local T=data.Transf3.t
				--<Translation x="T[1]" y="T[2]" z="T[3]" />
				local Translation_line=prepend..'<Translation'
				local Translation_line=Translation_line..' x=\"'..tostring(T[0]*1000)..'\" '
				local Translation_line=Translation_line..' y=\"'..tostring(T[1]*1000)..'\" '
				local Translation_line=Translation_line..' z=\"'..tostring(T[2]*1000)..'\" '
				local Translation_line=Translation_line..'/>\n'
				XmlFileHnd:write(Translation_line)
				----------------------------------
				--		Time
				----------------------------------
				--<Time t="1" />
				local Time=data.Time
				local Time_line=prepend..'<Time'
				local Time_line=Time_line..' t=\"'..tostring(Time)..'\" '
				local Time_line=Time_line..'/>\n'
				XmlFileHnd:write(Time_line)
				XmlFileHnd:write(Frame_prepend..'</Frame>\n')
			end
			Motion_prepend='\t'
			XmlFileHnd:write(Motion_prepend..'</Motion>\n')
	end
	local XMO_closer=
	XmlFileHnd:write('</Motions>')
	XmlFileHnd:close()
end